@@ -47,11 +47,11 @@ Pympz_mpmath_normalize(PyObject *self, PyObject *args)
     if(PyTuple_GET_SIZE(args) == 6){
         /* Need better error-checking here. Under Python 3.0, overflow into
            C-long is possible. */
-        sign = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 0));
+        sign = clong_From_Integer(PyTuple_GET_ITEM(args, 0));
         man = (PympzObject *)PyTuple_GET_ITEM(args, 1);
         exp = PyTuple_GET_ITEM(args, 2);
-        bc = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 3));
-        prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 4));
+        bc = clong_From_Integer(PyTuple_GET_ITEM(args, 3));
+        prec = clong_From_Integer(PyTuple_GET_ITEM(args, 4));
         rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 5))[0];
         if(PyErr_Occurred()){
             PyErr_SetString(PyExc_TypeError, "arguments long, PympzObject*,"
@@ -181,19 +181,36 @@ static PyObject *
 Pympz_mpmath_create(PyObject *self, PyObject *args)
 {
     long sign, bc, shift, zbits, carry = 0;
-    PyObject *exp = 0, *newexp = 0, *newexp2 = 0, *tmp = 0, *precobj = 0;
+    PyObject *exp = 0, *newexp = 0, *newexp2 = 0, *tmp = 0;
     PympzObject *man = 0, *upper = 0, *lower = 0;
 
-    char rnd = 'f';
+    const char *rnd = "f";
     long prec = 0;
 
-#if PY_MAJOR_VERSION >= 3
-    if(!PyArg_ParseTuple(args, "O&O|OC", Pympz_convert_arg, &man, &exp, &precobj, &rnd))
-#else
-    if(!PyArg_ParseTuple(args, "O&O|Oc", Pympz_convert_arg, &man, &exp, &precobj, &rnd))
-#endif
+    if(PyTuple_GET_SIZE(args) < 2) {
+        PyErr_SetString(PyExc_TypeError,
+                "mpmath_create() expects 'mpz','int'[,'int','str'] arguments");
         return NULL;
-    assert(Pympz_Check(man));
+    }
+
+    switch(PyTuple_GET_SIZE(args)) {
+        case 4:
+            rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 3));
+        case 3:
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 2));
+            if(prec == -1 && PyErr_Occurred())
+                return NULL;
+            prec = abs(prec);
+        case 2:
+            exp = PyTuple_GET_ITEM(args, 1);
+        case 1:
+            man = Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
+            if(!man) {
+                PyErr_SetString(PyExc_TypeError,
+                        "mpmath_create() expects 'mpz','int'[,'int','str'] arguments");
+                return NULL;
+            }
+    }
 
     /* If the mantissa is 0, return the normalized representation. */
     if(!mpz_sgn(man->z)) {
@@ -214,13 +231,11 @@ Pympz_mpmath_create(PyObject *self, PyObject *args)
     mpz_abs(upper->z, man->z);
     bc = mpz_sizeinbase(upper->z, 2);
 
-    /* Check desired precision */
-    if((precobj)&&(Py2or3Int_Check(precobj))) prec = abs(Py2or3Int_AsLong(precobj));
     if(!prec) prec = bc;
 
     shift = bc - prec;
     if(shift>0) {
-        switch(rnd) {
+        switch(rnd[0]) {
             case 'f':
                 if(sign) {
                     mpz_cdiv_q_2exp(upper->z, upper->z, shift);
@@ -411,7 +426,7 @@ do_mpmath_trim(mpz_t xman, mpz_t xexp, long prec, char rnd) {
 
 return_result:
     PyTuple_SET_ITEM(result, 0, (PyObject*)rman);
-    PyTuple_SET_ITEM(result, 1, Pympz_asindex(rexp));
+    PyTuple_SET_ITEM(result, 1, Pympz_To_Integer(rexp));
     Py_DECREF((PyObject*)rexp);
     return result;
 }
@@ -432,11 +447,11 @@ Pympz_mpmath_trim(PyObject *self, PyObject *args)
         case 4:
             rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 3));
         case 3:
-            prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 2));
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 2));
         case 2:
-            arg1 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 1));
+            arg1 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
         case 1:
-            arg0 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 0));
+            arg0 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
     }
     if(!arg0 || !arg1 || (prec < 0) || PyErr_Occurred()) {
         PyErr_SetString(PyExc_TypeError, "arguments mpz, mpz, long(>=0), char needed");
@@ -468,15 +483,15 @@ Pympz_mpmath_add(PyObject *self, PyObject *args)
         case 6:
             rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 5));
         case 5:
-            prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 4));
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 4));
         case 4:
-            arg3 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 3));
+            arg3 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 3));
         case 3:
-            arg2 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 2));
+            arg2 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
         case 2:
-            arg1 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 1));
+            arg1 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
         case 1:
-            arg0 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 0));
+            arg0 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
     }
     if(!arg0 || !arg1 || !arg2 || !arg3 || (prec < 0) || PyErr_Occurred()) {
         PyErr_SetString(PyExc_TypeError, "arguments mpz, mpz, mpz, mpz, long(>=0), char needed");
@@ -615,15 +630,15 @@ Pympz_mpmath_mult(PyObject *self, PyObject *args)
         case 6:
             rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 5));
         case 5:
-            prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 4));
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 4));
         case 4:
-            arg3 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 3));
+            arg3 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 3));
         case 3:
-            arg2 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 2));
+            arg2 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
         case 2:
-            arg1 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 1));
+            arg1 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
         case 1:
-            arg0 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 0));
+            arg0 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
     }
     if(!arg0 || !arg1 || !arg2 || !arg3 || (prec < 0) || PyErr_Occurred()) {
         PyErr_SetString(PyExc_TypeError, "arguments mpz, mpz, mpz, mpz, long(>=0), char needed");
@@ -665,15 +680,15 @@ Pympz_mpmath_div(PyObject *self, PyObject *args)
         case 6:
             rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 5));
         case 5:
-            prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 4));
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 4));
         case 4:
-            arg3 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 3));
+            arg3 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 3));
         case 3:
-            arg2 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 2));
+            arg2 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
         case 2:
-            arg1 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 1));
+            arg1 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
         case 1:
-            arg0 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 0));
+            arg0 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
     }
     if(!arg0 || !arg1 || !arg2 || !arg3 || (prec < 1) || PyErr_Occurred()) {
         PyErr_SetString(PyExc_TypeError, "arguments mpz, mpz, mpz, mpz, long(>=1), char needed");
@@ -772,11 +787,11 @@ Pympz_mpmath_sqrt(PyObject *self, PyObject *args)
         case 4:
             rnd = Py2or3String_AsString(PyTuple_GET_ITEM(args, 3));
         case 3:
-            prec = Py2or3Int_AsLong(PyTuple_GET_ITEM(args, 2));
+            prec = clong_From_Integer(PyTuple_GET_ITEM(args, 2));
         case 2:
-            arg1 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 1));
+            arg1 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
         case 1:
-            arg0 = (PyObject*)anyint2Pympz(PyTuple_GET_ITEM(args, 0));
+            arg0 = (PyObject*)Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
     }
     if(!arg0 || !arg1 || (prec < 1) || PyErr_Occurred()) {
         PyErr_SetString(PyExc_TypeError, "arguments mpz, mpz, long(>=1), char needed");
