@@ -1,6 +1,6 @@
-# partial unit test for gmpy 1.10 mpf functionality
+# partial unit test for gmpy 1.11 mpf functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.10
+# test-version 1.11
 r'''
 >>> filter(lambda x: not x.startswith('__'), dir(a))
 ['_copy', 'binary', 'ceil', 'digits', 'f2q', 'floor', 'getprec', 'getrprec', 'qdiv', 'reldiff', 'round', 'setprec', 'sign', 'sqrt', 'trunc']
@@ -319,8 +319,8 @@ mpf('1.23456e2',33)
 '0.000022'
 >>> _g.digits(_g.mpf(23.45))
 Traceback (most recent call last):
-  File "<stdin>", line 1, in ?
-TypeError: argument can not be converted to mpz
+  ...
+TypeError: digits() expects 'mpz',['int'] arguments
 >>> _g.fbinary('pep')
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -396,17 +396,23 @@ r'''
 
 def _test(chat=None):
     if chat:
-        print "Unit tests for gmpy 1.10 (mpf functionality)"
+        print "Unit tests for gmpy 1.11 (mpf functionality)"
         print "    running on Python %s" % sys.version
         print
-        print "Testing gmpy %s (GMP %s) with default caching (%s, %s, %s)" % (
-            (_g.version(), _g.gmp_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache()))
+        if _g.gmp_version():
+            print "Testing gmpy %s (GMP %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+        else:
+            print "Testing gmpy %s (MPIR %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+
     thismod = sys.modules.get(__name__)
     doctest.testmod(thismod, report=0)
 
     if chat: print "Repeating tests, with caching disabled"
-    _g.set_fcache(0)
+    _g.set_cache(0,128)
 
     sav = sys.stdout
     class _Dummy:
