@@ -1,9 +1,9 @@
-# partial unit test for gmpy 1.10 mpz functionality
+# partial unit test for gmpy 1.11 mpz functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.10
+# test-version 1.11
 r'''
 >>> filter(lambda x: not x.startswith('_'), dir(_g))
-['binary', 'bincoef', 'bit_length', 'cdivmod', 'ceil', 'comb', 'denom', 'digits', 'divexact', 'divm', 'f2q', 'fac', 'fbinary', 'fdigits', 'fdivmod', 'fib', 'floor', 'fround', 'fsign', 'fsqrt', 'gcd', 'gcdext', 'get_fcache', 'get_qcache', 'get_zcache', 'getbit', 'getprec', 'getrprec', 'gmp_limbsize', 'gmp_version', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'lcm', 'legendre', 'license', 'lowbits', 'mpf', 'mpir_version', 'mpq', 'mpz', 'next_prime', 'numdigits', 'numer', 'pi', 'popcount', 'qbinary', 'qdigits', 'qdiv', 'qsign', 'rand', 'reldiff', 'remove', 'root', 'scan0', 'scan1', 'set_debug', 'set_fcache', 'set_fcoform', 'set_minprec', 'set_qcache', 'set_tagoff', 'set_zcache', 'setbit', 'sign', 'sqrt', 'sqrtrem', 'tdivmod', 'trunc', 'version']
+['binary', 'bincoef', 'bit_length', 'cdivmod', 'ceil', 'comb', 'denom', 'digits', 'divexact', 'divm', 'f2q', 'fac', 'fbinary', 'fdigits', 'fdivmod', 'fib', 'floor', 'fround', 'fsign', 'fsqrt', 'gcd', 'gcdext', 'get_cache', 'getbit', 'getprec', 'getrprec', 'gmp_limbsize', 'gmp_version', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'lcm', 'legendre', 'license', 'lowbits', 'mpf', 'mpir_version', 'mpq', 'mpz', 'next_prime', 'numdigits', 'numer', 'pi', 'popcount', 'qbinary', 'qdigits', 'qdiv', 'qsign', 'rand', 'reldiff', 'remove', 'root', 'scan0', 'scan1', 'set_cache', 'set_debug', 'set_fcoform', 'set_minprec', 'set_tagoff', 'setbit', 'sign', 'sqrt', 'sqrtrem', 'tdivmod', 'trunc', 'version']
 >>> filter(lambda x: not x.startswith('__'), dir(a))
 ['_copy', 'binary', 'bincoef', 'bit_length', 'cdivmod', 'comb', 'digits', 'divexact', 'fdivmod', 'getbit', 'hamdist', 'invert', 'is_power', 'is_prime', 'is_square', 'jacobi', 'kronecker', 'legendre', 'lowbits', 'next_prime', 'numdigits', 'popcount', 'qdiv', 'remove', 'root', 'scan0', 'scan1', 'setbit', 'sign', 'sqrt', 'sqrtrem', 'tdivmod']
 >>>
@@ -122,6 +122,14 @@ mpz(124)
 mpz(-122)
 >>> (-1)-a
 mpz(-124)
+>>> a+True
+mpz(124)
+>>> a+False
+mpz(123)
+>>> a*False
+mpz(0)
+>>> a//True
+mpz(123)
 >>> abs(-a)==a
 1
 >>> pow(a,10)
@@ -471,14 +479,12 @@ mpz(246)
 mpz(61)
 >>> a<<-1
 Traceback (innermost last):
-  File "<pyshell#42>", line 1, in ?
-    a<<-1
-ValueError: Pympz_lshift negative shift count
+  ...
+ValueError: negative shift count
 >>> a>>-2
 Traceback (innermost last):
-  File "<pyshell#43>", line 1, in ?
-    a>>-2
-ValueError: Pympz_rshift negative shift count
+  ...
+ValueError: negative shift count
 >>> a<<0
 mpz(123)
 >>> a>>0
@@ -495,19 +501,16 @@ mpz(123)
 6
 >>> _g.hamdist(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.hamdist(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: hamdist() expects 'mpz','mpz' arguments
 >>> a.hamdist()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.hamdist()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: hamdist() expects 'mpz','mpz' arguments
 >>> a.hamdist(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.hamdist(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: hamdist() expects 'mpz','mpz' arguments
 >>> a.lowbits(5)
 mpz(27)
 >>> b.lowbits(5)
@@ -739,19 +742,16 @@ mpz(87)
 mpz(0)
 >>> _g.invert(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.invert(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: invert() expects 'mpz','mpz' arguments
 >>> a.invert()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.invert()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: invert() expects 'mpz','mpz' arguments
 >>> a.invert(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.invert(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: invert() expects 'mpz','mpz' arguments
 >>> _g.comb(3,-1)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -770,19 +770,16 @@ Traceback (most recent call last):
 ValueError: factor must be > 0
 >>> _g.remove(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.remove(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: remove() expects 'mpz','mpz' arguments
 >>> a.remove()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.remove()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: remove() expects 'mpz','mpz' arguments
 >>> a.remove(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.remove(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: remove() expects 'mpz','mpz' arguments
 >>> _g.is_prime(3,-3)
 Traceback (most recent call last):
   File "<stdin>", line 1, in ?
@@ -795,19 +792,16 @@ Traceback (most recent call last):
 ValueError: jacobi's y must be odd prime > 0
 >>> _g.jacobi(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.jacobi(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: jacobi() expects 'mpz','mpz' arguments
 >>> a.jacobi()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.jacobi()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: jacobi() expects 'mpz','mpz' arguments
 >>> a.jacobi(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.jacobi(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: jacobi() expects 'mpz','mpz' arguments
 >>> _g.legendre(10,3)
 1
 >>> _g.legendre(10,-3)
@@ -816,38 +810,32 @@ Traceback (most recent call last):
 ValueError: legendre's y must be odd and > 0
 >>> _g.legendre(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.legendre(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: legendre() expects 'mpz','mpz' arguments
 >>> a.legendre()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.legendre()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: legendre() expects 'mpz','mpz' arguments
 >>> a.legendre(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.legendre(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: legendre() expects 'mpz','mpz' arguments
 >>> _g.kronecker(10,3)
 1
 >>> _g.kronecker(10,-3)
 1
 >>> _g.kronecker(3)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    _g.kronecker(3)
-TypeError: function takes exactly 2 arguments (1 given)
+  ...
+TypeError: kronecker() expects 'mpz','mpz' arguments
 >>> a.kronecker()
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.kronecker()
-TypeError: function takes exactly 1 argument (0 given)
+  ...
+TypeError: kronecker() expects 'mpz','mpz' arguments
 >>> a.kronecker(3, 4)
 Traceback (innermost last):
-  File "<pyshell#184>", line 1, in ?
-    a.kronecker(3, 4)
-TypeError: function takes exactly 1 argument (2 given)
+  ...
+TypeError: kronecker() expects 'mpz','mpz' arguments
 >>> a=10L**20
 >>> b=a+39
 >>> _g.jacobi(a,b)
@@ -888,17 +876,23 @@ def _test(chat=None):
             del(__test__["special"])
 
     if chat:
-        print "Unit tests for gmpy 1.10 (mpz functionality)"
+        print "Unit tests for gmpy 1.11 (mpz functionality)"
         print "    running on Python %s" % sys.version
         print
-        print "Testing gmpy %s (GMP %s) with default caching (%s, %s, %s)" % (
-            (_g.version(), _g.gmp_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache()))
+        if _g.gmp_version():
+            print "Testing gmpy %s (GMP %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+        else:
+            print "Testing gmpy %s (MPIR %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+
     thismod = sys.modules.get(__name__)
     doctest.testmod(thismod, report=0)
 
     if chat: print "Repeating tests, with caching disabled"
-    _g.set_zcache(0)
+    _g.set_cache(0,128)
 
     sav = sys.stdout
     class _Dummy:
