@@ -1,6 +1,6 @@
-# partial unit test for gmpy 1.10 threaded mpz functionality
+# partial unit test for gmpy 1.11 threaded mpz functionality
 # relies on Tim Peters' "doctest.py" test-driver
-# test-version 1.10
+# test-version 1.11
 
 import gmpy as _g, doctest, sys, operator, gc, Queue, threading
 
@@ -68,12 +68,18 @@ def elemop(N=1000):
 
 def _test(chat=None):
     if chat:
-        print "Unit tests for gmpy 1.10 (threading)"
+        print "Unit tests for gmpy 1.11 (threading)"
         print "    running on Python", sys.version
         print
-        print "Testing gmpy %s (GMP %s) with default caching (%s, %s, %s)" % (
-            (_g.version(), _g.gmp_version(), _g.get_zcache(),
-            _g.get_qcache(), _g.get_fcache()))
+        if _g.gmp_version():
+            print "Testing gmpy %s (GMP %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+        else:
+            print "Testing gmpy %s (MPIR %s) with default caching (%s, %s)" % (
+                (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+                _g.get_cache()[1]))
+
     thismod = sys.modules.get(__name__)
     doctest.testmod(thismod, report=0)
 
