@@ -1,6 +1,6 @@
 r'''
 >>> gmpy.version()
-'1.10'
+'1.11'
 >>>
 '''
 
@@ -23,16 +23,16 @@ test_modules = (gmpy_test_cvr, gmpy_test_rnd, gmpy_test_mpf,
     gmpy_test_mpq, gmpy_test_mpz, gmpy_test_dec)
 
 _g = gmpy
-print("Unit tests for gmpy 1.10")
+print("Unit tests for gmpy 1.11")
 print("    on Python %s" % sys.version)
 if _g.gmp_version():
-    print("Testing gmpy %s (GMP %s), default caching (%s, %s, %s)" % (
-        (_g.version(), _g.gmp_version(), _g.get_zcache(),
-        _g.get_qcache(), _g.get_fcache())))
+    print("Testing gmpy %s (GMP %s), default caching (%s, %s)" % (
+        (_g.version(), _g.gmp_version(), _g.get_cache()[0],
+        _g.get_cache()[1])))
 else:
-    print("Testing gmpy %s (MPIR %s), default caching (%s, %s, %s)" % (
-        (_g.version(), _g.mpir_version(), _g.get_zcache(),
-        _g.get_qcache(), _g.get_fcache())))
+    print("Testing gmpy %s (MPIR %s), default caching (%s, %s)" % (
+        (_g.version(), _g.mpir_version(), _g.get_cache()[0],
+        _g.get_cache()[1])))
 
 pf, pt = 0, 0
 for x in test_modules:
